# Generated by Django 2.0.1 on 2018-11-19 21:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ohm2_accounts_light', '0002_auto_20181119_2052'),
    ]

    operations = [
        migrations.AlterField(
            model_name='passwordreset',
            name='code',
            field=models.CharField(max_length=255, unique=True),
        ),
    ]
